/**
 * Copyright 2020 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
interface FileWithDirectoryAndFileHandle extends File {
    directoryHandle?: FileSystemDirectoryHandle;
    handle?: FileSystemFileHandle;
}
/**
 * Read contents in a directory from disk using the File System Access API.
 *
 * @license © 2020 Google LLC. Licensed under the Apache License, Version 2.0.
 * @returns Contained files.
 */
declare function getFiles(dirHandle: FileSystemDirectoryHandle, recursive?: boolean, path?: string, skipDirectory?: (entry: FileSystemDirectoryHandle) => boolean, progress?: {
    loaded: number;
    total: number;
}, onProgress?: (event: ProgressEvent) => void): Promise<FileWithDirectoryAndFileHandle[]>;

/**
 * Reads the contents of a directory.
 *
 * @param dirHandle The directory to read. Could be the handle returned by `window.showDirectoryPicker()` or `DataTransferItem.getAsFileSystemHandle()`.
 * @param options Options for reading the directory.
 * @param options.recursive Whether to read the directory recursively.
 * @param options.skipDirectory A function to determine whether to skip a directory.
 * @returns Files in the directory.
 */
declare function readdir(dirHandle: FileSystemDirectoryHandle, options?: {
    recursive?: boolean;
    skipDirectory?: (entry: FileSystemDirectoryHandle) => boolean;
    onProgress?: (event: ProgressEvent) => void;
}): Promise<FileWithDirectoryAndFileHandle[]>;

export { type FileWithDirectoryAndFileHandle, readdir as default, getFiles, readdir };
