// src/lib/fs.ts
async function getFiles(dirHandle, recursive = false, path = dirHandle.name, skipDirectory, progress, onProgress) {
  const dirs = [];
  const files = [];
  progress = progress || { loaded: 0, total: 0 };
  for await (const entry of dirHandle.values()) {
    const nestedPath = `${path}/${entry.name}`;
    if (entry.kind === "file") {
      progress.total += 1;
      files.push(
        entry.getFile().then((f) => {
          const file = f;
          file.directoryHandle = dirHandle;
          file.handle = entry;
          progress.loaded += 1;
          onProgress?.(new ProgressEvent("progress", { lengthComputable: true, ...progress }));
          return Object.defineProperty(file, "webkitRelativePath", {
            configurable: true,
            enumerable: true,
            get: () => nestedPath
          });
        })
      );
    } else if (entry.kind === "directory" && recursive && (!skipDirectory || !skipDirectory(entry))) {
      dirs.push(getFiles(entry, recursive, nestedPath, skipDirectory, progress, onProgress));
    }
  }
  return [...(await Promise.all(dirs)).flat(), ...await Promise.all(files)];
}

// src/lib/index.ts
async function readdir(dirHandle, options) {
  return await getFiles(
    dirHandle,
    options?.recursive,
    void 0,
    options?.skipDirectory,
    void 0,
    options?.onProgress
  );
}
var lib_default = readdir;
export {
  lib_default as default,
  getFiles,
  readdir
};
/**
 * Read contents in a directory from disk using the File System Access API.
 *
 * @license © 2020 Google LLC. Licensed under the Apache License, Version 2.0.
 * @returns Contained files.
 */
//# sourceMappingURL=index.js.map